# AutoLGB

LightGBM + Optuna for no brainer

# Installation

Install using pip:
```bash
pip install autolgb
```

# Usage
Please refer to the [**Examples**](https://github.com/RektPunk/AutoLGB/tree/main/examples) provided for further clarification.
